@@ -124,22 +124,13 @@ static char *mime_encode(const unsigned char *data) {
  * NOTES:
  *   Calculate the difference between localtime and GMT/UTC.
  *
- *   This function does not recalculate the difference everytime it is called
- *   so it's possible that it will return the wrong value if your GMT offset
- *   changes while the process is loaded.
- *
  */
 static time_t get_gmtoffset(void) {
-	static time_t retval = -1;
+	time_t retval, gmt;
 
-	/* Return saved value. */
-	if (retval != -1) {
-		return(retval);
-	}
+	retval = gmt = time(NULL);
 
-	time(&retval);
-
-	retval -= mktime(gmtime(&retval));
+	retval -= mktime(gmtime(&gmt));
 
 	return(retval);
 }
@@ -177,13 +168,15 @@ static time_t mktime_from_rfc2616(const char *date) {
 		return(-1);
 	}
 
-	/* Fill in values from RFC-compliant string. */
+	currtime = time(NULL);
+
+	/* Fill in values from RFC-compliant string and adjust to localtime. */
 	timeinfo.tm_mday = atoi(date + 5);
 	timeinfo.tm_year = atoi(date + 12) - 1900;
 	timeinfo.tm_hour = atoi(date + 17);
 	timeinfo.tm_min = atoi(date + 20);
 	timeinfo.tm_sec = atoi(date + 23);
-	timeinfo.tm_isdst = 0; /* The date is in UTC and has no DST. */
+	timeinfo.tm_isdst = 0;
 
 	/* Determine month. */
 	timeinfo.tm_mon = -1;
@@ -202,8 +195,15 @@ static time_t mktime_from_rfc2616(const char *date) {
 	/* Calculate GMT offset. */
 	gmtoffset = get_gmtoffset();
 
-	/* Create GMT value */
-	currtime = mktime(&timeinfo) + gmtoffset;
+	/* Convert the time to a value. */
+	currtime = mktime(&timeinfo);
+	currtime += gmtoffset;
+#ifdef _USE_WIN32_
+	/* Win32 (Mingw32?) timezone calculations are screwy */
+	if (timeinfo.tm_isdst) {
+		currtime -= 3600;
+	}
+#endif
 
 	return(currtime);
 }
@@ -353,12 +353,13 @@ static time_t get_server_time(const char *host, unsigned int port, const char *p
 
 	/* Send the most simple HEAD request */
 	if (proxyhost == NULL) {
-		snprintf(out_buf, sizeof(out_buf), "HEAD / HTTP/1.0\r\nPragma: no-cache\r\nCache-Control: Max-age=0\r\n\r\n");
+		snprintf(out_buf, sizeof(out_buf), "HEAD / HTTP/1.0\r\n\r\n");
 	} else if (credentials == NULL) {
-		snprintf(out_buf, sizeof(out_buf), "HEAD http://%s:%i/ HTTP/1.0\r\nPragma: no-cache\r\nCache-Control: Max-age=0\r\n\r\n", host, port);
+		snprintf(out_buf, sizeof(out_buf), "HEAD http://%s:%i/ HTTP/1.0\r\n\r\n", host, port);
 	} else {
-		snprintf(out_buf, sizeof(out_buf), "HEAD http://%s:%i/ HTTP/1.0\r\nPragma: no-cache\r\nCache-Control: Max-age=0\r\nProxy-Authorization: Basic %s\r\n\r\n", host, port, credentials);
+		snprintf(out_buf, sizeof(out_buf), "HEAD http://%s:%i/ HTTP/1.0\r\nProxy-Authorization: Basic %s\r\n\r\n", host, port, credentials);
 	}
+
 	send(server_s, out_buf, strlen(out_buf), 0);
 
 	/* Receive data from the web server */
