@@ -83,6 +83,8 @@ static unsigned int timeind = 0;
 static unsigned int http_proxy_port = 0;
 static char *http_proxy = NULL;
 static long maxsleeptime = 43200, minsleeptime = 4096;
+static char *proxy_username = NULL;
+static char *proxy_password = NULL;
 
 #ifdef _USE_WIN32_
 /*
@@ -127,7 +129,7 @@ int htpd_loop(void) {
 	WorkLoopStatus = LOOP_RUN;
 
 	while (1) {
-		newtime = htp_calctime(timeservers, totaltimeservers, http_proxy, http_proxy_port);
+		newtime = htp_calctime(timeservers, totaltimeservers, http_proxy, http_proxy_port, proxy_username, proxy_password);
 
 		if (newtime != NULL) {
 			delta = set_clock(newtime, 1, 1);
@@ -136,12 +138,18 @@ int htpd_loop(void) {
 		}
 
 		/*
-		 *  Divide sleep time by 0.5 if change == 0  (check less frequently)
-		 *  Divide sleep time by 2   if change == 10 (check more frequently)
-		 *  Divide sleep time by 1   if change == 5  (check as frequently)
+		 *  If delta is 0.5s or less divide by 0.5s        (check less frequently)
+		 *  If delta is 1.0s or less subtract 60s          (check more frequently)
+		 *  If delta is greater than 1.0s divide by delta  (check more frequently)
 		 */
 		delta = fabs(delta);
-		sleeptime = ((double) sleeptime) / (((delta * delta) / 66.0) + 0.5);
+		if (delta <= 0.5) {
+			sleeptime *= 2;
+		} else if (delta <= 1.0) {
+			sleeptime -= 60;
+		} else {
+			sleeptime /= delta;
+		}
 
 		if (sleeptime < minsleeptime) {
 			sleeptime = minsleeptime;
@@ -423,6 +431,10 @@ static int daemon_stop(void) {
 		return(-1);
 	}
 
+#ifdef HAVE_SYSLOG
+	syslog(LOG_INFO, "Terminating running htpd (pid = %lu)\n", (unsigned long) pid);
+#endif
+
 	retval = 0;
 #else
 	/* Open a connection to the SCM if there isn't one already. */
@@ -737,15 +749,18 @@ int add_server(const char *shortvar, const char *var, const char *arguments, con
 
 int print_help(const char *shortvar, const char *var, const char *arguments, const char *value, lc_flags_t flags, void *extra) {
 	printf("htpd version " PACKAGE_VERSION "\n");
-	printf("Usage: htpd [-rkh] [-M max] [-m min] [-P proxy] [-H host [-H host [...]]]\n");
+	printf("Usage: htpd [-rkh] [-M max] [-m min] [-P proxy] [-U user] [-p pass]\n");
+	printf("            [-H host [-H host [...]]]\n");
 	printf("   -r        Remove service from startup.\n");
 	printf("   -k        Stop service.\n");
 	printf("   -h        This help.\n");
 	printf("   -M max    Maximum time between clock updates.\n");
 	printf("   -m min    Minimum time between clock updates.\n");
 	printf("   -P proxy  Proxy to send data through.\n");
+	printf("   -U user   Username for proxy authentication.\n");
+	printf("   -p pass   Password for proxy authentication.\n");
 	printf("   -H host   Host to query for time, can be in the format of:\n");
-	printf("             hostname[:port].   Default port is 80.\n");
+	printf("                 hostname[:port].   Default port is 80.\n");
 	exit(EXIT_SUCCESS);
 }
 
@@ -777,6 +792,8 @@ int main(int argc, char *argv[]) {
 	lc_register_callback("Stop", 'k', LC_VAR_NONE, htp_stop_svc, NULL);
 	lc_register_var("MaxSleep", LC_VAR_LONG, &maxsleeptime, 'M');
 	lc_register_var("MinSleep", LC_VAR_LONG, &minsleeptime, 'm');
+	lc_register_var("ProxyUser", LC_VAR_STRING, &proxy_username, 'U');
+	lc_register_var("ProxyPass", LC_VAR_STRING, &proxy_password, 'p');
 	lc_p_ret = lc_process(argc, argv, "htpd", LC_CONF_SPACE, SYSCONFDIR "/htpd.conf");
 	if (lc_p_ret < 0) {
 		fprintf(stderr, "Error processing configuration information: %s.\n", lc_geterrstr());
