@@ -4,6 +4,7 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
+#include "win32.h"
 
 #ifdef TIME_WITH_SYS_TIME
 #include <sys/time.h>
@@ -16,6 +17,6 @@
 #endif
 #endif
 
-int settimeofday(const struct timeval *tv ,  const  struct timezone *tz);
+int settimeofday(const struct timeval *tv , void *tz);
 
 #endif
